[Cmake-commits] CMake branch, next, updated. v2.8.10.2-2790-g556feed

Brad King brad.king at kitware.com
Wed Apr 17 10:32:03 EDT 2013


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
       via  556feed4c97679914ab02b73ecc052b04ce5eb0b (commit)
       via  5683146185a44e340452ee531e87099a51343897 (commit)
      from  5e3e2d36af071bbbbfbe9d40621ba8c32fcf0db7 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=556feed4c97679914ab02b73ecc052b04ce5eb0b
commit 556feed4c97679914ab02b73ecc052b04ce5eb0b
Merge: 5e3e2d3 5683146
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Wed Apr 17 10:32:01 2013 -0400
Commit:     CMake Topic Stage <kwrobot at kitware.com>
CommitDate: Wed Apr 17 10:32:01 2013 -0400

    Merge topic 'xcode-explicitFileType' into next
    
    5683146 Xcode: Use explicitFileType to mark source types (#14093)


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=5683146185a44e340452ee531e87099a51343897
commit 5683146185a44e340452ee531e87099a51343897
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Tue Apr 16 15:42:44 2013 -0400
Commit:     Brad King <brad.king at kitware.com>
CommitDate: Tue Apr 16 15:44:48 2013 -0400

    Xcode: Use explicitFileType to mark source types (#14093)
    
    Replace use of lastKnownFileType with explicitFileType to insist
    that Xcode treat the file as we ask.

diff --git a/Modules/CompilerId/Xcode-1.pbxproj.in b/Modules/CompilerId/Xcode-1.pbxproj.in
index f06960f..793ad02 100644
--- a/Modules/CompilerId/Xcode-1.pbxproj.in
+++ b/Modules/CompilerId/Xcode-1.pbxproj.in
@@ -56,7 +56,7 @@
 		2C18F0B415DC1DC700593670 = {
 			fileEncoding = 30;
 			isa = PBXFileReference;
-			lastKnownFileType = @id_type@;
+			explicitFileType = @id_type@;
 			path = @id_src@;
 			refType = 4;
 			sourceTree = "<group>";
diff --git a/Modules/CompilerId/Xcode-2.pbxproj.in b/Modules/CompilerId/Xcode-2.pbxproj.in
index e3c7aa9..226b413 100644
--- a/Modules/CompilerId/Xcode-2.pbxproj.in
+++ b/Modules/CompilerId/Xcode-2.pbxproj.in
@@ -7,7 +7,7 @@
 	objects = {
 
 		2C18F0B615DC1E0300593670 = {isa = PBXBuildFile; fileRef = 2C18F0B415DC1DC700593670; };
-		2C18F0B415DC1DC700593670 = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = @id_type@; path = @id_src@; sourceTree = "<group>"; };
+		2C18F0B415DC1DC700593670 = {isa = PBXFileReference; fileEncoding = 4; explicitFileType = @id_type@; path = @id_src@; sourceTree = "<group>"; };
 		8DD76F6C0486A84900D96B5E = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = CompilerId at id_lang@; sourceTree = BUILT_PRODUCTS_DIR; };
 
 		08FB7794FE84155DC02AAC07 = {
diff --git a/Modules/CompilerId/Xcode-3.pbxproj.in b/Modules/CompilerId/Xcode-3.pbxproj.in
index d94a803..6f861eb 100644
--- a/Modules/CompilerId/Xcode-3.pbxproj.in
+++ b/Modules/CompilerId/Xcode-3.pbxproj.in
@@ -7,7 +7,7 @@
 	objects = {
 
 		2C18F0B615DC1E0300593670 = {isa = PBXBuildFile; fileRef = 2C18F0B415DC1DC700593670; };
-		2C18F0B415DC1DC700593670 = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = @id_type@; path = @id_src@; sourceTree = "<group>"; };
+		2C18F0B415DC1DC700593670 = {isa = PBXFileReference; fileEncoding = 4; explicitFileType = @id_type@; path = @id_src@; sourceTree = "<group>"; };
 		08FB7794FE84155DC02AAC07 = {
 			isa = PBXGroup;
 			children = (
diff --git a/Source/cmGlobalXCodeGenerator.cxx b/Source/cmGlobalXCodeGenerator.cxx
index ceac564..2ecc64e 100644
--- a/Source/cmGlobalXCodeGenerator.cxx
+++ b/Source/cmGlobalXCodeGenerator.cxx
@@ -839,7 +839,7 @@ GetSourcecodeValueFromFileExtension(const std::string& _ext,
   //  // Already specialized above or we leave sourcecode == "sourcecode"
   //  // which is probably the most correct choice. Extensionless headers,
   //  // for example... Or file types unknown to Xcode that do not map to a
   //  // valid lastKnownFileType value.
   //  }
 
   return sourcecode;
@@ -882,7 +882,7 @@ cmGlobalXCodeGenerator::CreateXCodeFileReferenceFromPath(
 
   std::string sourcecode = GetSourcecodeValueFromFileExtension(ext, lang);
 
-  fileRef->AddAttribute("lastKnownFileType",
+  fileRef->AddAttribute("explicitFileType",
                         this->CreateString(sourcecode.c_str()));
 
   // Store the file path relative to the top of the source tree.
@@ -1003,7 +1003,7 @@ cmGlobalXCodeGenerator::CreateXCodeTargets(cmLocalGenerator* gen,
                                     *i, cmtarget);
       cmXCodeObject* fr = xsf->GetObject("fileRef");
       cmXCodeObject* filetype =
-        fr->GetObject()->GetObject("lastKnownFileType");
+        fr->GetObject()->GetObject("explicitFileType");
 
       cmTarget::SourceFileFlags tsFlags =
         cmtarget.GetTargetSourceFileFlags(*i);

-----------------------------------------------------------------------

Summary of changes:
 Modules/CompilerId/Xcode-1.pbxproj.in |    2 +-
@@ -839,7 +839,7 @@ GetSourcecodeValueFromFileExtension(const std::string& _ext,
   //  // which is probably the most correct choice. Extensionless headers,
   //  // for example... Or file types unknown to Xcode that do not map to a
-  //  // valid lastKnownFileType value.
+  //  // valid explicitFileType value.
   //  }
 
 Modules/CompilerId/Xcode-2.pbxproj.in |    2 +-
 Modules/CompilerId/Xcode-3.pbxproj.in |    2 +-
 Source/cmGlobalXCodeGenerator.cxx     |    6 +++---
 4 files changed, 6 insertions(+), 6 deletions(-)


hooks/post-receive
-- 
CMake


More information about the Cmake-commits mailing list